@@ -11,10 +11,10 @@ use strict;
 use warnings;
 
 package Dist::Zilla::PluginBundle::Author::RWSTAUNER;
-# git description: v4.206-4-g253a2cf
+# git description: v4.207-5-gcad7a51
 
 our $AUTHORITY = 'cpan:RWSTAUNER';
-$Dist::Zilla::PluginBundle::Author::RWSTAUNER::VERSION = '4.207';
+$Dist::Zilla::PluginBundle::Author::RWSTAUNER::VERSION = '4.208';
 # ABSTRACT: RWSTAUNER's Dist::Zilla config
 
 use Moose;
@@ -29,13 +29,7 @@ with qw(
 # Dist::Zilla::Role::DynamicConfig is not necessary: payload is already dynamic
 
 # don't require it in case it won't install somewhere
-my $spelling_tests = eval 'require Dist::Zilla::Plugin::Test::PodSpelling';
-
-# available builders
-my %builders = (
-  eumm => 'MakeMaker',
-  mb   => 'ModuleBuild',
-);
+my $spelling_tests = eval { require Dist::Zilla::Plugin::Test::PodSpelling; };
 
 # cannot use $self->name for class methods
 sub _bundle_name {
@@ -74,15 +68,6 @@ has auto_prereqs => (
   }
 );
 
-has builder => (
-  is         => 'ro',
-  isa        => enum( [ both => keys %builders ] ),
-  lazy       => 1,
-  default    => sub {
-    $_[0]->_config(builder => 'eumm');
-  }
-);
-
 has copy_files => (
   is         => 'ro',
   isa        => 'ArrayRef[Str]',
@@ -190,11 +175,12 @@ around BUILDARGS => sub {
   my $attr = $class->$orig(@args);
 
   # removed attributes
-  my %deprecated = (
+  my %removed = (
+    builder       => '-remove',
     disable_tests => '-remove',
     skip_prereqs  => 'AutoPrereqs.skip',
   );
-  while( my ($old, $new) = each %deprecated ){
+  while( my ($old, $new) = each %removed ){
     if( exists $attr->{payload}{ $old } ){
       die "$class no longer supports '$old'.\n  Please use '$new' instead.\n";
     }
@@ -400,17 +386,10 @@ sub configure {
     qw(
       ExecDir
       ShareDir
+      MakeMaker
     ),
   );
 
-  {
-    my @builders = $self->builder eq 'both'
-      ? (values %builders, 'DualBuilders')
-      : ($builders{ $self->builder });
-    $self->log("Including builders: @builders\n");
-    $self->add_plugins(@builders);
-  }
-
   $self->add_plugins(
   # generated t/ tests
     [ 'Test::ReportPrereqs' => { ':version' => '0.004' } ], # include/exclude
@@ -525,6 +504,7 @@ sub _generate_manifest_skip {
 ^(Build|Makefile)$
 \bpm_to_blib$
 ^MYMETA\.
+^cover_db/
 
 EOF_MANIFEST_SKIP
     }
@@ -551,7 +531,7 @@ Dist::Zilla::PluginBundle::Author::RWSTAUNER - RWSTAUNER's Dist::Zilla config
 
 =head1 VERSION
 
-version 4.207
+version 4.208
 
 =head1 SYNOPSIS
 
@@ -574,7 +554,6 @@ Possible options and their default values:
 
   authority      = cpan:RWSTAUNER
   auto_prereqs   = 1  ; enable AutoPrereqs
-  builder        = eumm ; or 'mb' or 'both'
   copy_files     =    ; space-separated list of additional files to copy from build
   fake_release   = 0  ; if true will use FakeRelease instead of 'releaser'
   install_command = cpanm -v -i . (passed to InstallRelease)
@@ -640,6 +619,7 @@ This bundle is roughly equivalent to the following (generated) F<dist.ini>:
   content     = ^(Build|Makefile)$
   content     = \bpm_to_blib$
   content     = ^MYMETA\.
+  content     = ^cover_db/
   filename    = MANIFEST.SKIP
   is_template = 1
 
